from setuptools import setup

setup(name='hyh_probability',
      version='0.1',
      description='Gaussian , Binomial distributions ',
      packages=['hyh_probability'],
      author = 'YehangHan',
      author_email = 'test@gmail.com',
      zip_safe=False)
